@@ -507,11 +507,26 @@ PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
         return;
     }
 
+    var colBg;
+    var colShadow;
+    var colBorder;
+
+    if (RSettings.hasDarkGuiBackground()) {
+        colBg = "#888888";
+        colShadow = "#333333";
+        colBorder = "black";
+    }
+    else {
+        colBg = "lightgray";
+        colShadow = "gray";
+        colBorder = "#c8c8c8";
+    }
+
     path = new RPainterPath();
     path.setPen(new QPen(Qt.NoPen));
-    path.setBrush(new QBrush(new QColor("lightgray")));
+    path.setBrush(new QBrush(new QColor(colBg)));
     path.addRect(new QRectF(-1.0e8, -1.0e8, 2.0e8, 2.0e8));
-    this.view.addToBackground(path);
+    this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
 
     // page border with shadow
     if (Print.getShowPaperBorders(document)) {
@@ -519,9 +534,9 @@ PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
         for (i = 0; i < pages.length; ++i) {
             path = new RPainterPath();
             path.setPen(new QPen(Qt.NoPen));
-            path.setBrush(new QBrush(new QColor("gray")));
+            path.setBrush(new QBrush(new QColor(colShadow)));
             this.drawShadow(path, pages[i]);
-            this.view.addToBackground(path);
+            this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
         }
 
         // paper background
@@ -532,16 +547,16 @@ PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
                     backgroundColor.blue());
             path.setBrush(new QBrush(color));
             this.drawPaper(path, pages[i]);
-            this.view.addToBackground(path);
+            this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
         }
 
         // paper border
         for (i = 0; i < pages.length; ++i) {
             path = new RPainterPath();
-            path.setPen(new QPen(new QColor(0xc8, 0xc8, 0xc8)));
+            path.setPen(new QPen(new QColor(colBorder)));
             path.setBrush(new QBrush(Qt.NoBrush));
             this.drawPaper(path, pages[i]);
-            this.view.addToBackground(path);
+            this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
         }
     }
 
@@ -563,17 +578,17 @@ PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
     for (i = 0; i < pages.length; ++i) {
         this.drawGlueMargins(path, pages[i]);
     }
-    this.view.addToBackground(path);
+    this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
 
-    // TODO: hook for page tags
+    // hook for page tags, footer, etc.:
     this.addDecorations(pages);
 
-    // crop marks
+    // crop marks:
     if (Print.getPrintCropMarks(document)) {
         for ( i = 0; i < pages.length; ++i) {
             path = new RPainterPath();
             Print.drawCropMarks(document, path, pages[i], false);
-            this.view.addToBackground(path);
+            this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
         }
     }
 
@@ -653,7 +668,11 @@ PrintPreviewImpl.prototype.slotPdfExport = function() {
         initialFileName = fileInfo.absoluteFilePath();
     }
 
-    var filterStrings = [ "PDF File (*.pdf)" ];
+    var filterStrings = [ "PDF File (*.pdf)",  "PDF/A-1B File (*.pdf)"];
+    if (RSettings.getQtVersion()<0x050A00) {
+        filterStrings = [ "PDF File (*.pdf)" ];
+    }
+
     filterStrings = translateFilterStrings(filterStrings);
 
     var ret = File.getSaveFileName(appWin, qsTr("Export to PDF"),
@@ -664,10 +683,14 @@ PrintPreviewImpl.prototype.slotPdfExport = function() {
     }
 
     var pdfFile = ret[0];
+    var pdfVersion = undefined;
+    if (ret[1].indexOf("PDF/A")!==-1) {
+        pdfVersion = "A-1B";
+    }
 
     appWin.handleUserMessage(qsTr("Exporting to %1...").arg(pdfFile));
 
-    var success = this.slotPrint(pdfFile);
+    var success = this.slotPrint(pdfFile, pdfVersion);
 
     if (success) {
         appWin.handleUserMessage(qsTr("Export complete: %1").arg(pdfFile));
@@ -685,18 +708,18 @@ PrintPreviewImpl.slotPdfExport = function() {
     pp.slotPdfExport();
 };
 
-PrintPreviewImpl.prototype.slotPrint = function(pdfFile) {
-    return PrintPreviewImpl.slotPrint(pdfFile);
+PrintPreviewImpl.prototype.slotPrint = function(pdfFile, pdfVersion) {
+    return PrintPreviewImpl.slotPrint(pdfFile, pdfVersion);
 };
 
 /**
  * Prints the drawing or exports it to the given PDF file.
  */
-PrintPreviewImpl.slotPrint = function(pdfFile) {
+PrintPreviewImpl.slotPrint = function(pdfFile, pdfVersion) {
     var mdiChild = EAction.getMdiChild();
     var view = mdiChild.getLastKnownViewWithFocus();
     var print = new Print(undefined, EAction.getDocument(), view);
-    return print.print(pdfFile);
+    return print.print(pdfFile, undefined, pdfVersion);
 };
 
 /**
