@@ -72,18 +72,30 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
         parent = RMainWindowQt.getMainWindow();
     }
 
-    var fileInfo = new QFileInfo(uiFile);
-    if (!fileInfo.exists() && !fileInfo.isAbsolute()) {
-        uiFile = basePath + "/" + uiFile;
+    var candidates;
+    if (!new QFileInfo(uiFile).isAbsolute()) {
+        candidates = [
+            uiFile,
+            basePath + "/" + uiFile,
+            ":" + uiFile,
+            ":" + basePath + "/" + uiFile
+        ];
+    }
+    else {
+        candidates = [
+            uiFile
+        ];
+    }
 
-        fileInfo = new QFileInfo(uiFile);
-        if (!fileInfo.exists()) {
-            uiFile = ":" + uiFile;
-            fileInfo = new QFileInfo(uiFile);
+    for (var i=0; i<candidates.length; i++) {
+        var candidate = candidates[i];
+        var fileInfo = new QFileInfo(candidate);
+        if (fileInfo.exists()) {
+            uiFile = candidate;
         }
     }
 
-    //fileInfo = new QFileInfo(uiFile);
+    var fileInfo = new QFileInfo(uiFile);
     if (!fileInfo.exists()) {
         qWarning("WidgetFactory: File %1 does not exist".arg(uiFile));
         return undefined;
@@ -124,6 +136,10 @@ WidgetFactory.createWidget = function(basePath, uiFile, parent) {
 WidgetFactory.createDialog = function(basePath, uiFile, parent) {
     var dialog = WidgetFactory.createWidget(basePath, uiFile, parent);
 
+    var flags = dialog.windowFlags();
+    flags = new Qt.WindowFlags(flags & ~(Qt.WindowContextHelpButtonHint));
+    dialog.setWindowFlags(flags);
+
     // a global function might be defined to do additional
     // initilization for all dialogs (e.g. for testing purposes):
     if (typeof(initDialog)!=="undefined") {
@@ -245,6 +261,9 @@ WidgetFactory.saveState = function(widget, group, document, map) {
             //value = [c.text, c.getDefaultUnit()];
             value = c.text;
         }
+        else if (isOfType(c, RMathComboBox)) {
+            value = c.currentText;
+        }
         else if (isOfType(c, QCheckBox)) {
             value = c.checked;
         }
@@ -297,6 +316,9 @@ WidgetFactory.saveState = function(widget, group, document, map) {
         else if (isOfType(c, QSpinBox) || isOfType(c, QDoubleSpinBox)) {
             value = c.value;
         }
+        else if (isOfType(c, QSlider)) {
+            value = c.value;
+        }
         else if (isOfType(c, QListWidget)) {
             var items = [];
             if (c.count != 0) {
@@ -563,6 +585,24 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             continue;
         }
+        if (isOfType(c, RMathComboBox)) {
+            WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
+            c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+            if (isNull(c.defaultValue)) {
+                //c.defaultValue = [c.text, c.getDefaultUnit()];
+                c.defaultValue = c.currentText;
+                c.slotTextChanged(c.currentText);
+            }
+            if (!isNull(value)) {
+                if (isString(value)) {
+                    c.currentText = value;
+                }
+                else {
+                    c.currentText = "%1".arg(value);
+                }
+            }
+            continue;
+        }
         if (isOfType(c, QToolButton) || isOfType(c, QPushButton)) {
 
             if (!c.group() && !c.autoExclusive) {
@@ -616,7 +656,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             else {
                 WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
                 c.toggled.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-                c.checked = (c.objectName == value);
+                if (value==="true") {
+                    c.checked = value;
+                }
+                else {
+                    c.checked = (c.objectName == value);
+                }
             }
             continue;
         }
@@ -791,6 +836,24 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             continue;
         }
+        if (isOfType(c, QSlider)) {
+            WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
+            c["valueChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+
+            if (isNull(c.defaultValue)) {
+                c.defaultValue = c.value;
+                if (signalReceiver!=undefined) {
+                    f = signalReceiver["slot" + c.objectName + "Changed"];
+                    if (isFunction(f)) {
+                        f.call(signalReceiver, c.value);
+                    }
+                }
+            }
+            if (!isNull(value)) {
+                c.value = value;
+            }
+            continue;
+        }
         if (isOfType(c, QListWidget)) {
             // the SaveContents property is set to false
             // if the list contents should not be saved to
@@ -902,7 +965,8 @@ WidgetFactory.processChildren = function(c) {
         isOfType(c, QComboBox) ||
         isOfType(c, QFontComboBox) ||
         isOfType(c, QPlainTextEdit) ||
-        isOfType(c, RMathLineEdit)) {
+        isOfType(c, RMathLineEdit) ||
+        isOfType(c, RMathComboBox)) {
 
         return false;
     }
@@ -984,12 +1048,16 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
                 }
             }
             // add line edit or math edit with maximum width:
-            if (isOfType(w, QLineEdit) || isOfType(w, RMathLineEdit)) {
+            if (isOfType(w, QLineEdit) || isOfType(w, RMathLineEdit) || isOfType(w, RMathComboBox)) {
                 if (w.maximumWidth>=1024) {
                     w.maximumWidth = 75;
                 }
             }
 
+            if (isOfType(w, RMathLineEdit) || isOfType(w, RMathComboBox)) {
+                WidgetFactory.initLineEditInfoTools(w);
+            }
+
             a = targetWidget.addWidget(w);
             a.objectName = w.objectName + "Action";
             ret.push(a);
@@ -1006,10 +1074,6 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
 };
 
 WidgetFactory.adjustIcons = function(includeBasePath, widget) {
-    if (!RSettings.hasDarkGuiBackground()) {
-        return;
-    }
-
     if (!isFunction(widget.children)) {
         return;
     }
@@ -1018,20 +1082,22 @@ WidgetFactory.adjustIcons = function(includeBasePath, widget) {
     for(var i=0;i<children.length;++i) {
         var w=children[i];
 
-        // adjust icon for dark themes:
+        // adjust icon for theme / dark mode:
         if (isOfType(w, QToolButton)) {
-            var iconFile = includeBasePath + "/" + w.objectName + "-inverse.svg";
-            if (new QFileInfo(iconFile).exists()) {
+            var iconFile = autoIconPath(includeBasePath + "/" + w.objectName + ".svg");
+            if (!isNull(iconFile)) {
                 w.icon = new QIcon(iconFile);
             }
         }
         else {
             WidgetFactory.adjustIcons(includeBasePath, w);
         }
-
     }
 };
 
+WidgetFactory.initLineEditInfoTools = function(mathLineEdit) {
+};
+
 /**
  * Adds an "insert symbol" menu entry to the context menu of the given
  * line edit.
@@ -1136,13 +1202,14 @@ WidgetFactory.initLayerCombo = function(comboBox, doc) {
     }
 
     comboBox.clear();
-    comboBox.iconSize = new QSize(32, 16);
+    comboBox.iconSize = new QSize(16, 10);
     var names = doc.getLayerNames();
+    //names = RS.sortAlphanumerical(names);
     names.sort(Array.alphaNumericalSorter);
     for (var i=0; i<names.length; i++) {
         var name = names[i];
         var layer = doc.queryLayer(name);
-        var icon = RColor.getIcon(layer.getColor());
+        var icon = RColor.getIcon(layer.getColor(), new QSize(comboBox.iconSize.width(),10));
         comboBox.addItem(icon, layer.getName());
     }
 };
@@ -1158,6 +1225,7 @@ WidgetFactory.initBlockCombo = function(comboBox, doc, showSpaces) {
     comboBox.clear();
     var names = doc.getBlockNames();
     names.sort(Array.alphaNumericalSorter);
+    //names = RS.sortAlphanumerical(names);
     for (var i=0; i<names.length; i++) {
         var name = names[i];
         if (showSpaces || !name.startsWith("*")) {
@@ -1201,6 +1269,27 @@ WidgetFactory.initVAlignCombo = function(comboBox) {
     comboBox.addItem(qsTr("Bottom"), RS.VAlignBottom);
 };
 
+WidgetFactory.initOrientationCombo = function(comboBox) {
+    comboBox.clear();
+
+    if (RSettings.isQt(5)) {
+        comboBox.addItem("↻ " + qsTr("Clockwise"), RS.CW);
+        comboBox.addItem("↺ " + qsTr("Counterclockwise"), RS.CCW);
+    }
+    else {
+        comboBox.addItem(qsTr("Clockwise"), RS.CW);
+        comboBox.addItem(qsTr("Counterclockwise"), RS.CCW);
+    }
+};
+
+WidgetFactory.initArcSymbolTypeCombo = function(comboBox) {
+    comboBox.clear();
+
+    comboBox.addItem(qsTr("Preceding"), 0);
+    comboBox.addItem(qsTr("Above"), 1);
+    comboBox.addItem(qsTr("None"), 2);
+};
+
 WidgetFactory.installComboBoxEventFilter = function(widget) {
     if (isNull(widget)) {
         return;
